@@ -19,6 +19,7 @@ except ImportError:
 
 class DjangoIntegration(Integration):
     HIGHLIGHT_HEADER = "HTTP_X_HIGHLIGHT_REQUEST"
+    INTEGRATION_KEY = "django"
 
     def __init__(self):
         self._orig_django = None
@@ -35,7 +36,11 @@ class DjangoIntegration(Integration):
             except (KeyError, ValueError):
                 pass
 
-            with highlight_io.H.get_instance().trace(session_id, request_id):
+            span_name = f"{environ.get('REQUEST_METHOD')} {environ.get('PATH_INFO')}"
+            qs = environ.get("QUERY_STRING")
+            if qs:
+                span_name = f"{span_name}?{qs}"
+            with highlight_io.H.get_instance().trace(span_name, session_id, request_id):
                 return self._orig_django(app, environ, start_response)
 
         WSGIHandler.__call__ = wrapped_call
