@@ -19,6 +19,7 @@ except ImportError:
 
 class FlaskIntegration(Integration):
     HIGHLIGHT_HEADER = "HTTP_X_HIGHLIGHT_REQUEST"
+    INTEGRATION_KEY = "flask"
 
     def __init__(self):
         self._orig_flask = None
@@ -35,7 +36,8 @@ class FlaskIntegration(Integration):
             except (KeyError, ValueError):
                 pass
 
-            with highlight_io.H.get_instance().trace(session_id, request_id):
+            span_name = f"{environ.get('REQUEST_METHOD')} {environ.get('REQUEST_URI')}"
+            with highlight_io.H.get_instance().trace(span_name, session_id, request_id):
                 return self._orig_flask(app, environ, start_response)
 
         Flask.__call__ = wrapped_call
